pilot.scheduler.data_compute_affinity_scheduler.Scheduler

Package pilot :: Package scheduler :: Module data_compute_affinity_scheduler :: Class Scheduler |

# Class Scheduler

source code

Instance Methods
__init__(self) | source code
set_pilot_data(self, pilot_data) set resources which are used for scheduling | source code
set_pilot_jobs(self, pilot_jobs) set resources which are used for scheduling | source code
schedule_pilot_data(self, data_unit_description=None) | source code
schedule_pilot_job(self, compute_unit_description=None) Enforces affinity description: if no PJ is available with the right affinity, WU can't be scheduled. | source code

Method Details

### schedule_pilot_job(self, compute_unit_description=None) | source code
Enforces affinity description: if no PJ is available with the right affinity, WU can't be scheduled. TODO: incorporate potential data movements to co-locate PD/WU